# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: document_db.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import document_pb2 as document__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64ocument_db.proto\x12\x17\x63ognica.rpc.db.document\x1a\x0e\x64ocument.proto\"\xf3\x01\n\tIndexDesc\x12\x10\n\x08index_id\x18\x01 \x01(\r\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x03(\t\x12\x0e\n\x06unique\x18\x04 \x01(\x08\x12\x36\n\nindex_type\x18\x05 \x01(\x0e\x32\".cognica.rpc.db.document.IndexType\x12\x34\n\x06status\x18\x07 \x01(\x0e\x32$.cognica.rpc.db.document.IndexStatus\x12\x32\n\x07options\x18\x08 \x01(\x0b\x32!.cognica.rpc.db.document.Document\"\x9e\x01\n\x0e\x43ollectionInfo\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x37\n\x0bprimary_key\x18\x02 \x01(\x0b\x32\".cognica.rpc.db.document.IndexDesc\x12:\n\x0esecondary_keys\x18\x03 \x03(\x0b\x32\".cognica.rpc.db.document.IndexDesc\"\x7f\n\x0bProfileInfo\x12\x0f\n\x07matched\x18\x01 \x01(\x04\x12\x0f\n\x07scanned\x18\x02 \x01(\x04\x12\x10\n\x08\x66iltered\x18\x03 \x01(\x04\x12\x19\n\x11query_duration_us\x18\x04 \x01(\x04\x12!\n\x19serialization_duration_us\x18\x05 \x01(\x04\"V\n\x17\x43reateCollectionRequest\x12;\n\ncollection\x18\x01 \x01(\x0b\x32\'.cognica.rpc.db.document.CollectionInfo\"r\n\x18\x43reateCollectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"0\n\x15\x44ropCollectionRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\"p\n\x16\x44ropCollectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"/\n\x14GetCollectionRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\"\xac\x01\n\x15GetCollectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12;\n\ncollection\x18\x03 \x01(\x0b\x32\'.cognica.rpc.db.document.CollectionInfo\x12\x35\n\x07profile\x18\x04 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"e\n\x12\x43reateIndexRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x36\n\nindex_desc\x18\x02 \x01(\x0b\x32\".cognica.rpc.db.document.IndexDesc\"m\n\x13\x43reateIndexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"?\n\x10\x44ropIndexRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t\"k\n\x11\x44ropIndexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\">\n\x0fGetIndexRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t\"\xbb\x01\n\x10GetIndexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x36\n\nindex_desc\x18\x04 \x01(\x0b\x32\".cognica.rpc.db.document.IndexDesc\x12\x35\n\x07profile\x18\x05 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"R\n\x05Query\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x30\n\x05query\x18\x02 \x01(\x0b\x32!.cognica.rpc.db.document.Document\"\xe4\x01\n\x0b\x46indRequest\x12-\n\x05query\x18\x01 \x01(\x0b\x32\x1e.cognica.rpc.db.document.Query\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x15\n\rindex_columns\x18\x03 \x03(\t\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12@\n\x06\x64types\x18\x05 \x03(\x0b\x32\x30.cognica.rpc.db.document.FindRequest.DtypesEntry\x1a-\n\x0b\x44typesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x0c\x46indResponse\x12\x13\n\x0bnum_columns\x18\x01 \x01(\x05\x12\x10\n\x08num_rows\x18\x02 \x01(\x05\x12\x0e\n\x06\x62uffer\x18\x03 \x01(\x0c\x12\x35\n\x07profile\x18\x04 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"J\n\x10\x46indBatchRequest\x12\x36\n\x08requests\x18\x01 \x03(\x0b\x32$.cognica.rpc.db.document.FindRequest\"M\n\x11\x46indBatchResponse\x12\x38\n\tresponses\x18\x01 \x03(\x0b\x32%.cognica.rpc.db.document.FindResponse\"=\n\x0c\x43ountRequest\x12-\n\x05query\x18\x01 \x01(\x0b\x32\x1e.cognica.rpc.db.document.Query\"v\n\rCountResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12\x35\n\x07profile\x18\x04 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"@\n\x0f\x43ontainsRequest\x12-\n\x05query\x18\x01 \x01(\x0b\x32\x1e.cognica.rpc.db.document.Query\"y\n\x10\x43ontainsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\x12\x35\n\x07profile\x18\x04 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"A\n\rInsertRequest\x12\x30\n\x08requests\x18\x01 \x03(\x0b\x32\x1e.cognica.rpc.db.document.Query\"h\n\x0eInsertResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"\x8f\x01\n\rUpdateRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x31\n\x06\x66ilter\x18\x02 \x01(\x0b\x32!.cognica.rpc.db.document.Document\x12\x32\n\x07updates\x18\x03 \x01(\x0b\x32!.cognica.rpc.db.document.Document\"h\n\x0eUpdateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"A\n\rRemoveRequest\x12\x30\n\x08requests\x18\x01 \x03(\x0b\x32\x1e.cognica.rpc.db.document.Query\"h\n\x0eRemoveResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"4\n\x19TruncateCollectionRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\"t\n\x1aTruncateCollectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07profile\x18\x03 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo\"\x18\n\x16ListCollectionsRequest\"\x8b\x01\n\x17ListCollectionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x03 \x03(\t\x12\x35\n\x07profile\x18\x04 \x01(\x0b\x32$.cognica.rpc.db.document.ProfileInfo*e\n\tIndexType\x12\x0f\n\x0bkPrimaryKey\x10\x00\x12\x11\n\rkSecondaryKey\x10\x01\x12\x1a\n\x16kClusteredSecondaryKey\x10\x02\x12\x18\n\x14kFullTextSearchIndex\x10\x03*\x8d\x01\n\x0bIndexStatus\x12\x0c\n\x08kEnabled\x10\x00\x12\r\n\tkDisabled\x10\x01\x12\x0f\n\x0bkReadyToUse\x10\x02\x12\x14\n\x10kBuildInProgress\x10\x03\x12\x12\n\x0ekBuildFinished\x10\x04\x12\x13\n\x0fkDropInProgress\x10\x05\x12\x11\n\rkDropFinished\x10\x06\x32\xbe\x0c\n\x11\x44ocumentDBService\x12U\n\x04\x66ind\x12$.cognica.rpc.db.document.FindRequest\x1a%.cognica.rpc.db.document.FindResponse\"\x00\x12\x65\n\nfind_batch\x12).cognica.rpc.db.document.FindBatchRequest\x1a*.cognica.rpc.db.document.FindBatchResponse\"\x00\x12X\n\x05\x63ount\x12%.cognica.rpc.db.document.CountRequest\x1a&.cognica.rpc.db.document.CountResponse\"\x00\x12\x61\n\x08\x63ontains\x12(.cognica.rpc.db.document.ContainsRequest\x1a).cognica.rpc.db.document.ContainsResponse\"\x00\x12[\n\x06insert\x12&.cognica.rpc.db.document.InsertRequest\x1a\'.cognica.rpc.db.document.InsertResponse\"\x00\x12[\n\x06update\x12&.cognica.rpc.db.document.UpdateRequest\x1a\'.cognica.rpc.db.document.UpdateResponse\"\x00\x12[\n\x06remove\x12&.cognica.rpc.db.document.RemoveRequest\x1a\'.cognica.rpc.db.document.RemoveResponse\"\x00\x12z\n\x11\x63reate_collection\x12\x30.cognica.rpc.db.document.CreateCollectionRequest\x1a\x31.cognica.rpc.db.document.CreateCollectionResponse\"\x00\x12t\n\x0f\x64rop_collection\x12..cognica.rpc.db.document.DropCollectionRequest\x1a/.cognica.rpc.db.document.DropCollectionResponse\"\x00\x12q\n\x0eget_collection\x12-.cognica.rpc.db.document.GetCollectionRequest\x1a..cognica.rpc.db.document.GetCollectionResponse\"\x00\x12w\n\x10list_collections\x12/.cognica.rpc.db.document.ListCollectionsRequest\x1a\x30.cognica.rpc.db.document.ListCollectionsResponse\"\x00\x12\x80\x01\n\x13truncate_collection\x12\x32.cognica.rpc.db.document.TruncateCollectionRequest\x1a\x33.cognica.rpc.db.document.TruncateCollectionResponse\"\x00\x12k\n\x0c\x63reate_index\x12+.cognica.rpc.db.document.CreateIndexRequest\x1a,.cognica.rpc.db.document.CreateIndexResponse\"\x00\x12\x65\n\ndrop_index\x12).cognica.rpc.db.document.DropIndexRequest\x1a*.cognica.rpc.db.document.DropIndexResponse\"\x00\x12\x62\n\tget_index\x12(.cognica.rpc.db.document.GetIndexRequest\x1a).cognica.rpc.db.document.GetIndexResponse\"\x00\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'document_db_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _FINDREQUEST_DTYPESENTRY._options = None
  _FINDREQUEST_DTYPESENTRY._serialized_options = b'8\001'
  _INDEXTYPE._serialized_start=3738
  _INDEXTYPE._serialized_end=3839
  _INDEXSTATUS._serialized_start=3842
  _INDEXSTATUS._serialized_end=3983
  _INDEXDESC._serialized_start=63
  _INDEXDESC._serialized_end=306
  _COLLECTIONINFO._serialized_start=309
  _COLLECTIONINFO._serialized_end=467
  _PROFILEINFO._serialized_start=469
  _PROFILEINFO._serialized_end=596
  _CREATECOLLECTIONREQUEST._serialized_start=598
  _CREATECOLLECTIONREQUEST._serialized_end=684
  _CREATECOLLECTIONRESPONSE._serialized_start=686
  _CREATECOLLECTIONRESPONSE._serialized_end=800
  _DROPCOLLECTIONREQUEST._serialized_start=802
  _DROPCOLLECTIONREQUEST._serialized_end=850
  _DROPCOLLECTIONRESPONSE._serialized_start=852
  _DROPCOLLECTIONRESPONSE._serialized_end=964
  _GETCOLLECTIONREQUEST._serialized_start=966
  _GETCOLLECTIONREQUEST._serialized_end=1013
  _GETCOLLECTIONRESPONSE._serialized_start=1016
  _GETCOLLECTIONRESPONSE._serialized_end=1188
  _CREATEINDEXREQUEST._serialized_start=1190
  _CREATEINDEXREQUEST._serialized_end=1291
  _CREATEINDEXRESPONSE._serialized_start=1293
  _CREATEINDEXRESPONSE._serialized_end=1402
  _DROPINDEXREQUEST._serialized_start=1404
  _DROPINDEXREQUEST._serialized_end=1467
  _DROPINDEXRESPONSE._serialized_start=1469
  _DROPINDEXRESPONSE._serialized_end=1576
  _GETINDEXREQUEST._serialized_start=1578
  _GETINDEXREQUEST._serialized_end=1640
  _GETINDEXRESPONSE._serialized_start=1643
  _GETINDEXRESPONSE._serialized_end=1830
  _QUERY._serialized_start=1832
  _QUERY._serialized_end=1914
  _FINDREQUEST._serialized_start=1917
  _FINDREQUEST._serialized_end=2145
  _FINDREQUEST_DTYPESENTRY._serialized_start=2100
  _FINDREQUEST_DTYPESENTRY._serialized_end=2145
  _FINDRESPONSE._serialized_start=2147
  _FINDRESPONSE._serialized_end=2271
  _FINDBATCHREQUEST._serialized_start=2273
  _FINDBATCHREQUEST._serialized_end=2347
  _FINDBATCHRESPONSE._serialized_start=2349
  _FINDBATCHRESPONSE._serialized_end=2426
  _COUNTREQUEST._serialized_start=2428
  _COUNTREQUEST._serialized_end=2489
  _COUNTRESPONSE._serialized_start=2491
  _COUNTRESPONSE._serialized_end=2609
  _CONTAINSREQUEST._serialized_start=2611
  _CONTAINSREQUEST._serialized_end=2675
  _CONTAINSRESPONSE._serialized_start=2677
  _CONTAINSRESPONSE._serialized_end=2798
  _INSERTREQUEST._serialized_start=2800
  _INSERTREQUEST._serialized_end=2865
  _INSERTRESPONSE._serialized_start=2867
  _INSERTRESPONSE._serialized_end=2971
  _UPDATEREQUEST._serialized_start=2974
  _UPDATEREQUEST._serialized_end=3117
  _UPDATERESPONSE._serialized_start=3119
  _UPDATERESPONSE._serialized_end=3223
  _REMOVEREQUEST._serialized_start=3225
  _REMOVEREQUEST._serialized_end=3290
  _REMOVERESPONSE._serialized_start=3292
  _REMOVERESPONSE._serialized_end=3396
  _TRUNCATECOLLECTIONREQUEST._serialized_start=3398
  _TRUNCATECOLLECTIONREQUEST._serialized_end=3450
  _TRUNCATECOLLECTIONRESPONSE._serialized_start=3452
  _TRUNCATECOLLECTIONRESPONSE._serialized_end=3568
  _LISTCOLLECTIONSREQUEST._serialized_start=3570
  _LISTCOLLECTIONSREQUEST._serialized_end=3594
  _LISTCOLLECTIONSRESPONSE._serialized_start=3597
  _LISTCOLLECTIONSRESPONSE._serialized_end=3736
  _DOCUMENTDBSERVICE._serialized_start=3986
  _DOCUMENTDBSERVICE._serialized_end=5584
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
#
# Cognica
#
# Copyright (c) 2023 Cognica, Inc.
#

import setuptools


setuptools.setup(
    name="cognica",
    description="Python client for Cognica database",
    long_description=open("README.md").read().strip(),
    long_description_content_type="text/markdown",
    keywords=[
        "Cognica",
        "key-value",
        "document store",
        "full-text search",
        "vector search",
        "search engine",
        "database",
    ],
    version="0.1.2",
    packages=setuptools.find_namespace_packages(where="src"),
    package_dir={"": "src"},
    url="https://github.com/cognicadb/cognica-python",
    project_urls={
        "Documentation": "https://github.com/cognicadb/cognica-python",
        "Changes": "https://github.com/cognicadb/cognica-python/releases",
        "Code": "https://github.com/cognicadb/cognica-python",
        "Issue tracker": "https://github.com/cognicadb/cognica-python/issues",
    },
    author="Cognica, Inc.",
    author_email="jaepil@cognica.io",
    license="Apache License 2.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    python_requires=">=3.7",
    install_requires=[
        "pandas>=1.5.3",
        "polars>=0.16.18",
        "pyarrow>=11.0.0",
        "grpcio>=1.53.0",
        "protobuf>=4.22.1",
    ],
    extras_require={"protobuf": ["grpcio>=1.43.0"]},
)
